aboutsummaryrefslogtreecommitdiff
path: root/engines/m4/animation.cpp
diff options
context:
space:
mode:
authorMatthew Hoops2011-05-25 11:17:11 -0400
committerMatthew Hoops2011-05-25 11:17:11 -0400
commit9539017ee35ce280758f22e589aa52c3baf9aaf3 (patch)
tree38578935a8649fcf2b052503365fbb5320a42103 /engines/m4/animation.cpp
parent7ff9f34aef3a89f167f1867fb31147571ba8112a (diff)
downloadscummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.tar.gz
scummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.tar.bz2
scummvm-rg350-9539017ee35ce280758f22e589aa52c3baf9aaf3.zip
ALL: initialise -> initialize
Diffstat (limited to 'engines/m4/animation.cpp')
-rw-r--r--engines/m4/animation.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/engines/m4/animation.cpp b/engines/m4/animation.cpp
index c89f74bd0a..39a3f175cd 100644
--- a/engines/m4/animation.cpp
+++ b/engines/m4/animation.cpp
@@ -61,9 +61,9 @@ MadsAnimation::~MadsAnimation() {
#define FILENAME_SIZE 13
/**
- * Initialises and loads the data of an animation
+ * Initializes and loads the data of an animation
*/
-void MadsAnimation::initialise(const Common::String &filename, uint16 flags, M4Surface *surface, M4Surface *depthSurface) {
+void MadsAnimation::initialize(const Common::String &filename, uint16 flags, M4Surface *surface, M4Surface *depthSurface) {
MadsPack anim(filename.c_str(), _vm);
bool madsRes = filename[0] == '*';
char buffer[20];
@@ -131,7 +131,7 @@ void MadsAnimation::initialise(const Common::String &filename, uint16 flags, M4S
if (flags & 0x100)
loadInterface(surface, depthSurface);
// Initialise the reference list
for (int i = 0; i < spriteListCount; ++i)
_spriteListIndexes.push_back(-1);
@@ -266,7 +266,7 @@ void MadsAnimation::initialise(const Common::String &filename, uint16 flags, M4S
* Loads an animation file for display
*/
void MadsAnimation::load(const Common::String &filename, int abortTimers) {
- initialise(filename, 0, NULL, NULL);
+ initialize(filename, 0, NULL, NULL);
_messageCtr = 0;
_skipLoad = true;
@@ -279,7 +279,7 @@ void MadsAnimation::load(const Common::String &filename, int abortTimers) {
}
*/
// Initialise miscellaneous fields
_currentFrame = 0;
_oldFrameEntry = 0;
_nextFrameTimer = _madsVm->_currentTimer;
@@ -289,7 +289,7 @@ void MadsAnimation::load(const Common::String &filename, int abortTimers) {
if (_madsVm->_scene)
_actionNouns = _madsVm->scene()->_action._action;
// Initialise kernel message list
for (uint i = 0; i < _messages.size(); ++i)
_messages[i].kernelMsgIndex = -1;
}
@@ -131,7 +131,7 @@ void MadsAnimation::initialise(const Common::String &filename, uint16 flags, M4S
if (flags & 0x100)
loadInterface(surface, depthSurface);
- // Initialise the reference list
+ // Initialize the reference list
for (int i = 0; i < spriteListCount; ++i)
_spriteListIndexes.push_back(-1);
@@ -279,7 +279,7 @@ void MadsAnimation::load(const Common::String &filename, int abortTimers) {
}
*/
- // Initialise miscellaneous fields
+ // Initialize miscellaneous fields
_currentFrame = 0;
_oldFrameEntry = 0;
@@ -289,7 +289,7 @@ void MadsAnimation::load(const Common::String &filename, int abortTimers) {
if (_madsVm->_scene)
_actionNouns = _madsVm->scene()->_action._action;
- // Initialise kernel message list
+ // Initialize kernel message list
for (uint i = 0; i < _messages.size(); ++i)
_messages[i].kernelMsgIndex = -1;